- year
is a numeric vector
- period
is a numeric vector, period of the year, if the parameter
freq is "Q" then it will be an integer between 1 and 3.
If freq is "S" then it will be an integer between 1 and 2.
- cod
is a numeric vector. Brazilian Institute of Geography and
Statistics (IBGE) code assigned to each municipality and state.
- freq
is a character, periodicity of publication of the report,
"S" is semiannual, "Q" is four-month period. The semiannual
periodicity ("S") applies only to municipalities with less than 50
thousand inhabitants that opted for simplified publication. Default is
"Q"
- annex
is a numeric vector, an integer between 1 and 6.
Default is NULL, it will get all attachments.
- power
is a character vector, an acronym for each power,
executive "E", legislative "L", judiciary "J",
public ministry "M", Public defense "D".
Default is c("E", "L", "J", "M", "D")
- sphere
is a string vector. Sphere filter "M" = Municipalities, "E" = States and "DF", "U" = Union and "C" = Consortium. Default is NULL
- verbose
is a logical. Enable verbose mode. Default is FALSE